==> package-manager-1.99.1.tar.gz: package-manager-1.99.1/setup/setup-help.c <==
#include <config.h>
#include <stdio.h>

#include <badpenguin-ansi.h>
#include <badpenguin-errors.h>
#include <badpenguin-untar.h>
#include "package-setup.h"
#include "setup-quit.h"

void setup_help(void) {
  printTITLE("Siamo spiacenti, l'help in linea e' da completare :-)\n\n");
  libbadpenguin_version();
  // Header
  printf( "%s=============================================\n",FG_WHITE);
  printf( "%sBad Penguin - Installatore Pacchetti %sv. %s\n",FG_RED, FG_BLUE, VERSION);
  printf( "%s@1998-99,2000 by Antonio Gallo <agx@linux.it>\n", FG_YELLOW);
  printf( "%s=============================================\n\n",FG_WHITE);
  // Commands
  printf( "%sInstallazione veloce:  setup /cdrom/agxlinux/packages/base/mc.bpp\n", FG_GREEN);
  normal_color();
  printf(   "Installazione remota:  setup --install pkgname.bpp [TargetDir]\n" );
  printf(   "Upgrade ............:  setup --upgrade pkgname     [TargetDir]\n" );
  printf(   "Rimozione ..........:  setup --remove  pkgname     [TargetDir]\n" );
  printf(   "Clean Up / Purge ...:  setup --cleanup pkgname     [TargetDir]\n" );
  printf(   "Restore ............:  setup --restore pkgname     [TargetDir]\n" );
  printf(   "Update .............:  setup --update  pkgname     [TargetDir]\n" );
  
  // Options
  printf( "\nOpzioni disponibili:\n" );
  printf( "   -v --verbose : visualizza informazioni di debug\n" );
  printf( "   -v -v        : visualizza molte informazioni di debug\n" );
  printf( "   -f --force   : forza il comando senza chiedere conferme\n" );
  printf( "      --relaxed : annulla il comando senza chiedere conferme\n" );
  setup_quit( ERROR_HELP );
}

==> package-manager-1.99.4.tar.gz: package-manager-1.99.4/setup/setup-help.c <==
#include <config.h>
#include <stdio.h>

#include <badpenguin-ansi.h>
#include <badpenguin-errors.h>
#include <badpenguin-untar.h>
#include "package-setup.h"
#include "setup-quit.h"

void setup_help(void) {
  printTITLE("Siamo spiacenti, l'help in linea e' da completare :-)\n\n");
  libbadpenguin_version();
  // Header
  printf( "%s=============================================\n",FG_WHITE);
  printf( "%sBad Penguin - Installatore Pacchetti %sv. %s\n",FG_RED, FG_BLUE, VERSION);
  printf( "%s@1998-99,2000 by Antonio Gallo <agx@linux.it>\n", FG_YELLOW);
  printf( "%s=============================================\n\n",FG_WHITE);
  // Commands
  printf( "%sInstallazione veloce:  setup /cdrom/agxlinux/packages/base/mc.bpp\n", FG_GREEN);
  normal_color();
  printf(   "Installazione remota:  setup --install pkgname.bpp [TargetDir]\n" );
  printf(   "Upgrade ............:  setup --upgrade pkgname     [TargetDir]\n" );
  printf(   "Rimozione ..........:  setup --remove  pkgname     [TargetDir]\n" );
  printf(   "Clean Up / Purge ...:  setup --cleanup pkgname     [TargetDir]\n" );
  printf(   "Restore ............:  setup --restore pkgname     [TargetDir]\n" );
  printf(   "Update .............:  setup --update  pkgname     [TargetDir]\n" );
  
  // Options
  printf( "\nOpzioni disponibili:\n" );
  printf( "   -v --verbose : visualizza informazioni di debug\n" );
  printf( "   -v -v        : visualizza molte informazioni di debug\n" );
  printf( "      --force   : forza il comando senza chiedere conferme\n" );
  printf( "      --relaxed : annulla il comando senza chiedere conferme\n" );
  printf( "      --no-deps : non installa le dipende (TODO)\n" );
  setup_quit( ERROR_HELP );
}
